@@ -284,10 +284,24 @@
 		}
 	}
 
-	var lang = $('HTML').attr('lang') || $('HTML').attr('xml:lang') || 'en';
-	$.getScript('/--static--/ztfy.thesaurus/js/i18n/' + lang + '.js');
 
-	// Initialize thesaurus views
+	/**
+	 * Init I18n strings
+	 */
+	$.ZTFY.thesaurus.I18n = {
+
+		CONFIRM_UNSELECT_WITH_CHILD: "Removing this term from this extract will also remove all it's specific terms. Are you sure?"
+
+	}
+
+	var lang = $('HTML').attr('lang') || $('HTML').attr('xml:lang');
+	if (lang && (lang != 'en'))
+		$.ZTFY.getScript('/--static--/ztfy.thesaurus/js/i18n/' + lang + '.js');
+
+
+	/**
+	 * Initialize thesaurus events
+	 */
 	$(document).ready(function() {
 		$('DIV.extract').on('click', 'SPAN.showhide', $.ZTFY.thesaurus.tree.showHideExtract);
 		$('DIV.tree').on('click', 'SPAN.square', $.ZTFY.thesaurus.tree.switchExtract);
